[Bug middle-end/77484] [6/7 Regression] Static branch predictor causes ~6-8% regression of SPEC2000 GAP

hubicka at ucw dot cz gcc-bugzilla@gcc.gnu.org
Thu Dec 1 15:59:00 GMT 2016


https://gcc.gnu.org/bugzilla/show_bug.cgi?id=77484

--- Comment #8 from Jan Hubicka <hubicka at ucw dot cz> ---
> Yes that's it, a single run shows 12% speedup with this patch!

Looks promising.  We probably should try to differentiate from polymorphic
calls
as virtual methods are also used in different patterns.  
let me cook the patch.

Honza


More information about the Gcc-bugs mailing list